@@ -7,14 +7,16 @@ show_diagnostic_results <- function(results, diagnostic) {
       call_color(call),
       file_color(file),
       file_color(line_number),
-      if (is.na(replacement)) '' else sprintf('Potential replacement:\n%s\n', replacement_color(replacement))
+      if (is.na(replacement)) '' else gettextf('Potential replacement:\n%s\n', replacement_color(replacement))
     ))]
   }
 }
 
-diagnostic_schema = function() data.table(
-  call = character(),
-  file = character(),
-  line_number = integer(),
-  replacement = character()
-)
+diagnostic_schema = function() {
+  data.table(
+    call = character(),
+    file = character(),
+    line_number = integer(),
+    replacement = character()
+  )
+}
