@@ -43,7 +43,7 @@ test_that("translate_package works on a simple package", {
     {
       expect_messages(
         translate_package(pkg, verbose=TRUE),
-        c("Generating .pot files", "No languages provided"),
+        c("No languages provided"),
         fixed = TRUE
       )
 
@@ -69,7 +69,7 @@ test_that("translate_package works on a simple package", {
     {
       expect_messages(
         translate_package(pkg, "zh_CN", verbose=TRUE),
-        c("Beginning new translations", "BEGINNING TRANSLATION", '"Installing" translations with msgfmt'),
+        c("Beginning new translations", "BEGINNING TRANSLATION", "Recompiling 'zh_CN' R translation"),
         fixed = TRUE
       )
 
@@ -173,7 +173,8 @@ test_that('Unknown language flow works correctly', {
       'How would you refer to this language in English?',
       'received the same set of templates',
       'received 2 unique templated arguments',
-      'received 4 unique templated arguments'
+      'received 4 unique templated arguments',
+      'received 5 unique templated arguments'
     ),
     fixed=TRUE
   )
@@ -236,7 +237,16 @@ test_that("Packages with src code work correctly", {
       expect(
         any(grepl("inst/po/zh_CN/LC_MESSAGES/rSrcMsg.mo", pkg_files, fixed = TRUE)),
         sprintf(
-          "Didn't find rSrcMsg.mo; found %s.\n**Sysreq paths: %s.\n**po/zh_CN contents:\n%s\n**Direct msgfmt output:\n%s**Session info:\n%s",
+          paste(
+            "Didn't find rSrcMsg.mo; found %s.",
+            "**Sysreq paths: %s.",
+            "**po/zh_CN contents:",
+            "%s",
+            "**Direct msgfmt output:",
+            "%s**Session info:",
+            "%s",
+            sep = "\n"
+          ),
           toString(pkg_files), toString(Sys.which(potools:::SYSTEM_REQUIREMENTS)),
           paste(readLines(file.path(pkg, 'po/zh_CN.po')), collapse='\n'),
           {
